cal.MyPresences (My presences) — amici1

# `cal.MyPresences` (My presences)

Columns

- `<django.db.models.fields.BigAutoField: id>`

- `<django.db.models.fields.related.ForeignKey: event>`

- `<django.db.models.fields.related.ForeignKey: partner>`

- `<django.db.models.fields.related.ForeignKey: role>`

- `<lino.core.choicelists.ChoiceListField: state>`

- `<django.db.models.fields.CharField: remark>`

Detail fields

- `<Panel main_1 in lino_xl.lib.cal.ui.GuestDetail on lino_xl.lib.cal.ui.Guests>`

- `<Panel main_2 in lino_xl.lib.cal.ui.GuestDetail on lino_xl.lib.cal.ui.Guests>`

- Remark (remark) : See `<django.db.models.fields.CharField: remark>`.

Actions

- HTML (show_as_html) : Show this table in Bootstrap3 interface

- Table (landscape) (as_pdf) : Show this table as a pdf document.

- Table (portrait) (as_pdf_p) : Show this table as a pdf document.

- Export to .xls (export_excel) : Export this table as an .xls document

- None (grid_post) : See `<lino.core.actions.CreateRow grid_post>`.

- None (grid_put) : See `<lino.core.actions.SaveGridCell grid_put>`.

- New (insert) : Open a dialog window to insert a new Presence.

- Create (submit_insert) : Create the record and open a detail window on it

- Detail (detail) : Open a detail window on this record.

- Delete (delete_selected) : Delete this record

- None (grid) : See `<lino.core.actions.ShowTable grid>`.

- None (open_help) : See `<lino.core.actions.OpenHelpWindow open_help>`.

- None (validate) : See `<lino.core.actions.ValidateForm validate>`.

- Save (submit_detail) : Save changes in this form

- ☑ (wf1) : Present

- ☉ (wf2) : Missing

- ⚕ (wf3) : Excused

- ? (wf4) : Invited

Filter parameters

- `<django.db.models.fields.related.ForeignKey: user>`

- `<lino.core.fields.DummyField object at 0x7fc826444668>`

- `<django.db.models.fields.related.ForeignKey: partner>`

- `<lino.core.choicelists.ChoiceListField: event_state>`

- `<lino.core.choicelists.ChoiceListField: guest_state>`

- `<django.db.models.fields.DateField: start_date>`

- `<django.db.models.fields.DateField: end_date>`

## Filter parameters